@@ -2,7 +2,7 @@ package Net::ACME::Crypt;
 
 #----------------------------------------------------------------------
 # This module exists because of a desire to do these computations
-# in pure Perl, for environments where a compiler may not be available.
+# in environments where a compiler may not be available.
 # (Otherwise, CryptX would be ideal.)
 #----------------------------------------------------------------------
 
@@ -16,6 +16,8 @@ use JSON              ();
 use Math::BigInt      ();
 use MIME::Base64      ();
 
+use Net::ACME::EvalBug ();
+
 *_encode_b64u = \&MIME::Base64::encode_base64url;
 
 #This can be set ahead of time if desired.
@@ -54,7 +56,8 @@ sub get_rsa_jwk_thumbprint {
 }
 
 #Based on Crypt::JWT::encode_jwt(), but focused on this particular
-#protocol’s needs.
+#protocol’s needs. Note that UTF-8 will probably get mangled in here,
+#but that’s not a problem since ACME shouldn’t require sending raw UTF-8.
 sub create_rs256_jwt {
     my ( %args ) = @_;
 
@@ -112,7 +115,8 @@ sub _try_to_load_module {
 
     return 0 if $INC{$path};
 
-    local $@;
+    local $@ if !Net::ACME::EvalBug::bug_exists();
+
     return eval { require($path); 1 };
 }
 
@@ -139,6 +143,9 @@ sub _sign_with_key_via_openssl_binary {
     print {$d_fh} $msg or die "write($d_path): $!";
     close $d_fh;
 
+    #Works across exec().
+    local $?;
+
     my $sig = qx/$OPENSSL_BIN_PATH dgst -sha256 -sign $path $d_path/;
     die if $?;
 
@@ -148,6 +155,8 @@ sub _sign_with_key_via_openssl_binary {
 sub _encode_json {
     my ($payload) = @_;
 
+    #Always do a canonical encode so that we can test more easily.
+    #Note that JWS itself does NOT require this.
     return JSON->new()->canonical(1)->encode($payload);
 }
 
