@@ -5,16 +5,24 @@ use warnings;
 
 use Carp ();
 
-my $_OVERLOADED;
+use Net::ACME::EvalBug ();
+
+my %_OVERLOADED;
 
 sub _check_overload {
     my ( $class, $str ) = @_;
 
-    $_OVERLOADED ||= eval qq{
+    local $@ if !Net::ACME::EvalBug::bug_exists();
+
+    $_OVERLOADED{$class} ||= eval qq{
         package $class;
         use overload (q<""> => __PACKAGE__->can('__spew'));
+        1;
     };
 
+    #Should never happen as long as overload.pm is available.
+    die if !$_OVERLOADED{$class};
+
     return;
 }
 
